/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef FLOAT64EDITOR_H
#define FLOAT64EDITOR_H

// lib
#include "../types/float64.h"
// KDE
#include <KLineEdit>


class Float64Editor : public KLineEdit
{
  Q_OBJECT
  Q_PROPERTY( Float64 data READ data WRITE setData USER true )

  public:
    explicit Float64Editor( QWidget* parent );

    virtual ~Float64Editor();

  public:
    void setData( Float64 data );
    Float64 data() const;
};

#endif
